<?php

namespace Drupal\video_embed_vkontakte\Plugin\video_embed_field\Provider;

use Drupal\video_embed_field\ProviderPluginBase;
use GuzzleHttp\Exception\RequestException;

/**
 * @VideoEmbedProvider(
 *   id = "vkontakte",
 *   title = @Translation("Vkontakte")
 * )
 */
class Vkontakte extends ProviderPluginBase {

  /**
   * {@inheritdoc}
   */
  public function renderEmbedCode($width, $height, $autoplay) {
    // @todo is it possible use autoplay?
    return [
      '#type' => 'html_tag',
      '#tag' => 'iframe',
      '#attributes' => [
        'width' => $width,
        'height' => $height,
        'frameborder' => '0',
        'allowfullscreen' => 'allowfullscreen',
        'src' => $this->getInput(),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getRemoteThumbnailUrl() {
    try {
      $response = $this->httpClient->get($this->getInput());
      $data = $response->getBody()->getContents();
      preg_match('/<video id="video_player" poster="(?<img>.*)".*>/U', $data, $matches);
      return isset($matches['img']) ? $matches['img'] : '';
    }
    catch (RequestException $exception) {}
  }

  /**
   * @param $iframe
   *  IFrame of video.
   *
   * @return string
   *  The direct video url.
   */
  public static function getUrlFromiFrame($iframe) {
    preg_match('/^<iframe.*src="\/\/(?<id>.*)".*<\/iframe>$/U', $iframe, $matches);

    return isset($matches['id']) ? 'https://' . $matches['id'] : '';
  }

  /**
   * {@inheritdoc}
   */
  public static function getIdFromInput($input) {
    return static::getComponent($input, 'oid') . '_' . static::getComponent($input, 'id') . '_' . static::getComponent($input, 'hash');
  }

  /**
   * Get a component from the URL.
   *
   * @param string $input
   *   The input URL.
   * @param string $component
   *   The component from the regex to get.
   *
   * @return string
   *   The value of the match in the regex.
   */
  protected static function getComponent($input, $component) {
    preg_match('/^https:\/\/vk\.com\/video_ext\.php\?oid=-(?<oid>[\d]*)&id=(?<id>[\d]*)&hash=(?<hash>[\da-z]{16}).*$/', $input, $matches);

    return isset($matches[$component]) ? $matches[$component] : '';
  }

}
